@@ -26,7 +26,8 @@ QGIS utilities module
 
 """
 
-from qgis.PyQt.QtCore import QCoreApplication, QLocale, QThread, qDebug
+from qgis.PyQt.QtCore import QCoreApplication, QLocale, QThread, qDebug, QUrl
+from qgis.PyQt.QtGui import QDesktopServices
 from qgis.PyQt.QtWidgets import QPushButton, QApplication
 from qgis.core import Qgis, QgsMessageLog, qgsfunction, QgsMessageOutput
 from qgis.gui import QgsMessageBar
@@ -499,8 +500,13 @@ def reloadPlugin(packageName):
     startPlugin(packageName)
 
 
-def showPluginHelp(packageName=None, filename="index", section=""):
-    """ show a help in the user's html browser. The help file should be named index-ll_CC.html or index-ll.html"""
+def showPluginHelp(packageName: str = None, filename: str = "index", section: str = ""):
+    """Open help in the user's html browser. The help file should be named index-ll_CC.html or index-ll.html or index.html.
+
+    :param str packageName: name of package folder, if None it's using the current file package. Defaults to None. Optional.
+    :param str filename: name of file to open. It can be a path like 'doc/index' for example. Defaults to 'index'.
+    :param str section: URL path to open. Defaults to empty string.
+    """
     try:
         source = ""
         if packageName is None:
@@ -526,7 +532,7 @@ def showPluginHelp(packageName=None, filename="index", section=""):
         url = "file://" + helpfile
         if section != "":
             url = url + "#" + section
-        iface.openURL(url, False)
+        QDesktopServices.openUrl(QUrl(url))
 
 
 def pluginDirectory(packageName):
@@ -780,7 +786,7 @@ def _import(name, globals={}, locals={}, fromlist=[], level=None):
                 global _RemoveDllDirectory
 
                 for p in set(new_path.split(';')) - set(old_path.split(';')):
-                    if p is not None and p not in _import_path:
+                    if p is not None and p not in _import_path and os.path.isdir(p):
                         _import_paths[p] = _AddDllDirectory(p)
 
                 for p in set(old_path.split(';')) - set(new_path.split(';')):
@@ -791,7 +797,7 @@ def _import(name, globals={}, locals={}, fromlist=[], level=None):
 
     mod = _builtin_import(name, globals, locals, fromlist, level)
 
-    if mod and '__file__' in mod.__dict__:
+    if mod and getattr(mod, '__file__', None):
         module_name = mod.__name__ if fromlist else name
         package_name = module_name.split('.')[0]
         # check whether the module belongs to one of our plugins
